==> qtjambi-help-debuginfo-macos-5.15.17.jar: sources/QtJambiHelp/QHelpIndexModel_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtHelp/qhelpindexwidget.h>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/QMap>
#include <QtCore/qurl.h>
#include <QtHelp/qhelpenginecore.h>
#include <QtCore/QStringList>
#include <QtCore/qnamespace.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qdatastream.h>
#include <QtCore/QVector>
#include <QtCore/QList>
#include <QtCore/qsize.h>
#include <QtCore/QHash>
#include <QtCore/qbytearray.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <QtCore/qtimer.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qcoreevent.h>
#include <QtCore/qthread.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QHelpIndexModel_0(){
    static int result = QMetaMethod::fromSignal(&QHelpIndexModel::indexCreated).methodIndex();
    return result;
}


int __signal_method_indexes_QHelpIndexModel_1(){
    static int result = QMetaMethod::fromSignal(&QHelpIndexModel::indexCreationStarted).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpIndexModel::createIndex(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpIndexModel_createIndex_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring customFilterName0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpIndexModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpIndexModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpIndexModel::createIndex(QString)", __qt_this)
        QString  __qt_customFilterName0 = qtjambi_cast<QString >(__jni_env, customFilterName0);
        __qt_this->createIndex(__qt_customFilterName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpIndexModel::filter(QString,QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpIndexModel_filter_1native_1cref_1QString_1cref_1QString__JLjava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring filter0,
 jstring wildcard1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHelpIndexModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpIndexModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpIndexModel::filter(QString,QString)", __qt_this)
        QString  __qt_filter0 = qtjambi_cast<QString >(__jni_env, filter0);
        QString  __qt_wildcard1 = qtjambi_cast<QString >(__jni_env, wildcard1);
        QModelIndex __qt_return_value = __qt_this->filter(__qt_filter0, __qt_wildcard1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpIndexModel::helpEngine()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpIndexModel_helpEngine_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpIndexModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpIndexModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpIndexModel::helpEngine()const", __qt_this)
        QHelpEngineCore* __qt_return_value = __qt_this->helpEngine();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpIndexModel::isCreatingIndex()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpIndexModel_isCreatingIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpIndexModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpIndexModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpIndexModel::isCreatingIndex()const", __qt_this)
        __java_return_value = __qt_this->isCreatingIndex();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpIndexModel::linksForKeyword(QString)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpIndexModel_linksForKeyword_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring keyword0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpIndexModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpIndexModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpIndexModel::linksForKeyword(QString)const", __qt_this)
        QString  __qt_keyword0 = qtjambi_cast<QString >(__jni_env, keyword0);
        QMap<QString, QUrl> __qt_return_value = __qt_this->linksForKeyword(__qt_keyword0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QHelpIndexModel(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHelpIndexModel>("QHelpIndexModel", "io/qt/help/QHelpIndexModel");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QHelpIndexModel::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "indexCreated", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QHelpIndexModel_0),
                SignalMetaInfo(/* 1 */ "indexCreationStarted", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QHelpIndexModel_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QHelpIndexModel_0()){ // indexCreated()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QHelpIndexModel_1()){ // indexCreationStarted()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-help-debuginfo-macos-6.6.0.jar: sources/QtJambiHelp/QHelpIndexModel_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelpindexwidget.h>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtHelp/qhelpenginecore.h>
#include <QtCore/QStringList>
#include <QtCore/QMap>
#include <QtCore/qnamespace.h>
#include <QtCore/qmimedata.h>
#include <QtCore/QList>
#include <QtCore/qsize.h>
#include <QtCore/qdatastream.h>
#include <QtCore/QHash>
#include <QtCore/qbytearray.h>
#include <QtCore/qproperty.h>
#include <QtCore/qvariant.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qobject.h>
#include <QtCore/qcoreevent.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qtimer.h>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qthread.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QHelpIndexModel_0(){
    static int result = QMetaMethod::fromSignal(&QHelpIndexModel::indexCreated).methodIndex();
    return result;
}


int __signal_method_indexes_QHelpIndexModel_1(){
    static int result = QMetaMethod::fromSignal(&QHelpIndexModel::indexCreationStarted).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpIndexModel::createIndex(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpIndexModel_createIndex_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring customFilterName0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpIndexModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpIndexModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpIndexModel::createIndex(QString)", __qt_this)
        QString  __qt_customFilterName0 = qtjambi_cast<QString>(__jni_env, customFilterName0);
        __qt_this->createIndex(__qt_customFilterName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpIndexModel::filter(QString,QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpIndexModel_filter_1native_1cref_1QString_1cref_1QString__JLjava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring filter0,
 jstring wildcard1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHelpIndexModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpIndexModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpIndexModel::filter(QString,QString)", __qt_this)
        QString  __qt_filter0 = qtjambi_cast<QString>(__jni_env, filter0);
        QString  __qt_wildcard1 = qtjambi_cast<QString>(__jni_env, wildcard1);
        QModelIndex __qt_return_value = __qt_this->filter(__qt_filter0, __qt_wildcard1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpIndexModel::helpEngine()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpIndexModel_helpEngine_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpIndexModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpIndexModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpIndexModel::helpEngine()const", __qt_this)
        QHelpEngineCore* __qt_return_value = __qt_this->helpEngine();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpIndexModel::isCreatingIndex()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpIndexModel_isCreatingIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpIndexModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpIndexModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpIndexModel::isCreatingIndex()const", __qt_this)
        __java_return_value = __qt_this->isCreatingIndex();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QHelpIndexModel(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHelpIndexModel>("QHelpIndexModel", "io/qt/help/QHelpIndexModel");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QHelpIndexModel::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "indexCreated", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QHelpIndexModel_0),
                SignalMetaInfo(/* 1 */ "indexCreationStarted", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QHelpIndexModel_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QHelpIndexModel_0()){ // indexCreated()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QHelpIndexModel_1()){ // indexCreationStarted()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
